<?php

namespace App\Http\Controllers\Auth;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Http;

class AuthController extends Controller
{
    public function login_view()
    {
        // Redirect to the home page if already logged in
        if (session()->has('bearer_token')) {
            return redirect()->route('home');
        }

        return view('auth.login');
    }
    public function login(Request $request)
    {
        // Validate the request
        $request->validate([
            'email' => 'required|email',
            'password' => 'required',
        ]);

        $apiBaseUrl = env('API_BASE_URL');
        $response = Http::post("$apiBaseUrl/login", [
            'email' => $request->email,
            'password' => $request->password,
        ]);

        if ($response->successful()) {
            $data = $response->json();
            $token = 'Bearer ' . $data['access_token'];
            $role = $data['role'];
            $permissions = $data['permissions'];
            $org_id = $data['org_id'];
            $id = $data['id'];
            $logo = $data['logo'];
            $employee_id = $data['employee_id'];

            // Store token, role, and permissions in the session
            session([
                'bearer_token' => $token,
                'role' => $role,
                'permissions' => $permissions,
                'org_id' => $org_id,
                'id' => $id,
                'logo' => $logo,
                'employee_id' => $employee_id,
            ]);

            // Redirect to the dashboard with a success message
            return redirect('/')->with('success', 'Logged in successfully');
        }

        // Pass the API response message to the login view as error
        $message = $response->json('message', 'Credentials did not match');
        return redirect()->route('login_view')->with('error', $message);
    }

    public function logout(Request $request)
    {
        $token = session('bearer_token');
        $apiBaseUrl = env('API_BASE_URL');
      
        $response = Http::withToken($token)->post("$apiBaseUrl/logout");

        if ($response->successful()) {
            session()->forget(['bearer_token', 'role', 'permissions','org_id','id','logo','employee_id']);
            return redirect()->route('login_view')->with('success', 'Logged out successfully');
        } else {


            return redirect()->route('login_view')->with('error', 'Unable to logout');
        }
    }


    public function home()
    {
        try {
            // Retrieve the token from the session
            $token = session('bearer_token');
            $org_id = session('org_id');
            $role = session('role'); // Assuming you store the role in the session
    
            // Retrieve the base API URL from environment variables
            $apiBaseUrl = env('API_BASE_URL');
    
            // Make the API request with the token
            $response = Http::withToken($token)->get("{$apiBaseUrl}/dashboard");
    
            // Check if the response is successful
            if ($response->successful()) {
                // Decode the JSON response
                $data = $response->json();
                
                // Pass the data and role to the view
                return view('admin.dashboard', compact('data', 'role'));
            } else {
                // Return a 404 response if the data is not found
                return response()->json(['status' => 404, 'message' => 'Dashboard data not found.'], 404);
            }
        } catch (\Exception $e) {
            // Handle exceptions and return an error response
            return response()->json(['message' => 'An error occurred: ' . $e->getMessage()], 500);
        }
    }
    
}
